summaryrefslogtreecommitdiffstats
path: root/src/com/android/camera/VideoModule.java
diff options
context:
space:
mode:
authorSuman Mukherjee <sumam@codeaurora.org>2014-04-23 13:02:07 +0530
committerGerrit - the friendly Code Review server <code-review@localhost>2014-04-23 04:38:02 -0700
commite49881abbc4a135a2c8cbc1754081b9a12de5051 (patch)
tree6b37c75f777ce207b7559c3596ecfecab1f961e2 /src/com/android/camera/VideoModule.java
parent4180872a42f636db1d6c4b6e68a08bef95e189ee (diff)
downloadandroid_packages_apps_Snap-e49881abbc4a135a2c8cbc1754081b9a12de5051.tar.gz
android_packages_apps_Snap-e49881abbc4a135a2c8cbc1754081b9a12de5051.tar.bz2
android_packages_apps_Snap-e49881abbc4a135a2c8cbc1754081b9a12de5051.zip
Camera: Block HFR option for Video HDR
Video HDR can’t work with HFR and that caused AEC behaviour change. Fix Made: User'll be notified that HFR/HSR selection is not allowed for HDR mode. After that, HFR selection will be set to off and the option will be disabled. It'll not be vice versa as HDR has higher priority than HFR. Change-Id: I4b0f8362667a53e46a83223cab77b7248e1410e2 CRs-Fixed: 652078
Diffstat (limited to 'src/com/android/camera/VideoModule.java')
-rw-r--r--src/com/android/camera/VideoModule.java9
1 files changed, 6 insertions, 3 deletions
diff --git a/src/com/android/camera/VideoModule.java b/src/com/android/camera/VideoModule.java
index abfab4833..1fab44268 100644
--- a/src/com/android/camera/VideoModule.java
+++ b/src/com/android/camera/VideoModule.java
@@ -2031,9 +2031,10 @@ public class VideoModule implements CameraModule,
} else
mParameters.setVideoHDRMode("off");
//HFR/HSR recording not supported for DIS and/ TimeLapse option
String hfr = mParameters.getVideoHighFrameRate();
String hsr = mParameters.get("video-hsr");
+ String hdr = mParameters.getVideoHDRMode();
if ( ((hfr != null) && (!hfr.equals("off"))) ||
((hsr != null) && (!hsr.equals("off"))) ) {
// Read time lapse recording interval.
@@ -2041,8 +2042,10 @@ public class VideoModule implements CameraModule,
CameraSettings.KEY_VIDEO_TIME_LAPSE_FRAME_INTERVAL,
mActivity.getString(R.string.pref_video_time_lapse_frame_interval_default));
int timeLapseInterval = Integer.parseInt(frameIntervalStr);
- if ((timeLapseInterval != 0) || (disMode.equals("enable")) ) {
- Log.v(TAG,"DIS/Time Lapse ON for HFR/HSR selection, turning HFR/HSR off");
+ if ( (timeLapseInterval != 0) ||
+ (disMode.equals("enable")) ||
+ ((hdr != null) && (!hdr.equals("off"))) ) {
+ Log.v(TAG,"HDR/DIS/Time Lapse ON for HFR/HSR selection, turning HFR/HSR off");
Toast.makeText(mActivity, R.string.error_app_unsupported_hfr_selection,
Toast.LENGTH_LONG).show();
mParameters.setVideoHighFrameRate("off");
@@ -2031,9 +2031,10 @@ public class VideoModule implements CameraModule,
} else
mParameters.setVideoHDRMode("off");
- //HFR/HSR recording not supported for DIS and/ TimeLapse option
+ //HFR/HSR recording not supported with DIS,TimeLapse,HDR option
String hfr = mParameters.getVideoHighFrameRate();
String hsr = mParameters.get("video-hsr");